pub struct RoundMinersResponse {
pub round_id: u64,
pub miners: Vec<RoundMiner>,
pub authority: Option<RoundMiner>,
pub authority_rank: Option<u64>,
}Expand description
Response type for listing miners in a round.
Fields
round_id: u64miners: Vec<RoundMiner>Miners sorted by total_deployed descending, paginated.
The pinned authority’s data (included regardless of pagination rank). Null if no authority was provided or they didn’t deploy in this round.
The pinned authority’s 1-based rank by total_deployed descending. Null if no authority was provided or they didn’t deploy in this round.